@@ -5,7 +5,8 @@
 #![allow(clippy::nonminimal_bool)]
 #![allow(clippy::wrong_self_convention)]
 
-use swc_common::{input::StringInput, BytePos, SourceFile};
+use swc_common::{input::StringInput, SourceFile};
+use swc_html_ast::{Document, DocumentFragment, Element};
 
 use crate::{
     error::Error,
@@ -32,33 +33,11 @@ where
     }
 }
 
-/// Parse a given string as `T`.
-///
-/// If there are syntax errors but if it was recoverable, it will be appended
-/// `errors`.
-pub fn parse_str<'a, T>(
-    src: &'a str,
-    start_pos: BytePos,
-    end_pos: BytePos,
-    config: ParserConfig,
-    errors: &mut Vec<Error>,
-) -> PResult<T>
-where
-    Parser<Lexer<StringInput<'a>>>: Parse<T>,
-{
-    let lexer = Lexer::new(StringInput::new(src, start_pos, end_pos), config);
-    let mut parser = Parser::new(lexer, config);
-
-    let res = parser.parse();
-    errors.extend(parser.take_errors());
-    res
-}
-
 /// Parse a given file as `T`.
 ///
 /// If there are syntax errors but if it was recoverable, it will be appended to
 /// `errors`.
-pub fn parse_file<'a, T>(
+pub fn parse_file_as<'a, T>(
     fm: &'a SourceFile,
     config: ParserConfig,
     errors: &mut Vec<Error>,
@@ -68,8 +47,46 @@ where
 {
     let lexer = Lexer::new(StringInput::from(fm), config);
     let mut parser = Parser::new(lexer, config);
+    let result = parser.parse();
 
-    let res = parser.parse();
     errors.extend(parser.take_errors());
-    res
+
+    result
+}
+
+/// Parse a given file as `Document`.
+///
+/// If there are syntax errors but if it was recoverable, it will be appended to
+/// `errors`.
+pub fn parse_file_as_document(
+    fm: &SourceFile,
+    config: ParserConfig,
+    errors: &mut Vec<Error>,
+) -> PResult<Document> {
+    let lexer = Lexer::new(StringInput::from(fm), config);
+    let mut parser = Parser::new(lexer, config);
+    let result = parser.parse_document();
+
+    errors.extend(parser.take_errors());
+
+    result
+}
+
+/// Parse a given file as `DocumentFragment`.
+///
+/// If there are syntax errors but if it was recoverable, it will be appended to
+/// `errors`.
+pub fn parse_file_as_document_fragment(
+    fm: &SourceFile,
+    context_element: Element,
+    config: ParserConfig,
+    errors: &mut Vec<Error>,
+) -> PResult<DocumentFragment> {
+    let lexer = Lexer::new(StringInput::from(fm), config);
+    let mut parser = Parser::new(lexer, config);
+    let result = parser.parse_document_fragment(context_element);
+
+    errors.extend(parser.take_errors());
+
+    result
 }
